@@ -4,7 +4,10 @@ from CoreData import *
 
 class TestNSManagedObject (TestCase):
     def testMethods(self):
-        o = NSManagedObject.alloc().init()
+        descr = NSEntityDescription.alloc().init()
+        descr.setName_(b'Name'.decode('ascii'))
+        o = NSManagedObject.alloc().initWithEntity_insertIntoManagedObjectContext_(descr, None)
+
         self.assertResultIsBOOL(o.isInserted)
         self.assertResultIsBOOL(o.isUpdated)
         self.assertResultIsBOOL(o.isDeleted)
@@ -35,6 +38,10 @@ class TestNSManagedObject (TestCase):
         self.assertEqual(NSSnapshotEventRefresh, 1 << 5)
         self.assertEqual(NSSnapshotEventMergePolicy, 1 << 6)
 
+    @min_os_level("10.7")
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(NSManagedObject.hasChanges)
+
 
 if __name__ == "__main__":
     main()
